==> pyrubika-2.0.1.tar.gz: pyrubika-2.0.1/setup.py <==
import os
import re
from setuptools import setup

_long_description = """

## An example:
``` python
from pyrubika.pyrubika import pyrubika

bot = pyrubika("Auth Account")

gap = "guids"

bot.sendMessage(gap,"pyrubika")
```


### How to import the Rubik's library

``` bash
from pyrubika.pyrubika import pyrubika
```

### How to install the library

``` bash
pip install pyrubika
```

### My ID in Rubika

``` bash
@mamadcoder1
```
## And My ID Channel in Rubika

``` bash
@python_java_source 
```
"""

setup(
    name = "pyrubika",
    version = "2.0.1",
    author = "mamadcoder",
    author_email = "mamadcoder@gmail.com",
    description = ("Another example of the library making the Rubik's robot"),
    license = "MIT",
    keywords = ["rubika","bot","robot","library","rubikalib","rubikalib.ml","rubikalib.ir","rubika.ir","Rubika","Python","Pyrubika","pyrubika"],
    url = "https://rubika.ir/python_java_source",
    packages=['pyrubika'],
    long_description=_long_description,
    long_description_content_type = 'text/markdown',
    classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    "Programming Language :: Python :: Implementation :: PyPy",
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10'
    ],
)

==> pyrubika-2.0.2.tar.gz: pyrubika-2.0.2/setup.py <==
import os
import re
from setuptools import setup

_long_description = """

## An example:
``` python
from pyrubika.pyrubika import pyrubika

bot = pyrubika("Auth Account")

gap = "guids"

bot.sendMessage(gap,"pyrubika")
```


### How to import the Rubik's library

``` bash
from pyrubika.pyrubika import pyrubika
```

### How to install the library

``` bash
pip install pyrubika==2.0.2
```

### My ID in Rubika

``` bash
@mamadcoder1
```
## And My ID Channel in Rubika

``` bash
@python_java_source 
```
"""

setup(
    name = "pyrubika",
    version = "2.0.2",
    author = "mamadcoder",
    author_email = "mamadcoder@gmail.com",
    description = ("Another example of the library making the Rubik's robot"),
    license = "MIT",
    keywords = ["rubika","bot","robot","library","rubikalib","rubikalib.ml","rubikalib.ir","rubika.ir","Rubika","Python","Pyrubika","pyrubika"],
    url = "https://rubika.ir/python_java_source",
    packages=['pyrubika'],
    long_description=_long_description,
    long_description_content_type = 'text/markdown',
    classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    "Programming Language :: Python :: Implementation :: PyPy",
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10'
    ],
)
